@@ -8,13 +8,14 @@ import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSele
 import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowsProperties;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.DimensionRow;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.mapping.ColumnMappingData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.mapping.ColumnMappingList;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.CellData;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
 
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.core.client.GWT;
@@ -49,32 +50,29 @@ import com.sencha.gxt.widget.core.client.form.FieldLabel;
  * 
  */
 public class ColumnMappingPanel extends FramedPanel {
-	protected static final String WIDTH = "520px";
-	protected static final String HEIGHT = "400px";
-	protected static final String COMBOWIDTH = "220px";
-	protected static final String CONTAINERHEIGHT = "340px";
-	protected static final String CONTAINERWIDTH = "500px";
+	private static final String COMBOWIDTH = "220px";
+	private static final String CONTAINERHEIGHT = "340px";
+	private static final String CONTAINERWIDTH = "500px";
 
-	protected ColumnMappingPanel thisPanel;
+	private ColumnMappingPanel thisPanel;
+	private ColumnMappingDialog parent;
+	private ColumnData selectedColumn;
+	private ColumnData referenceColumn;
+	private EventBus eventBus;
 
-	protected ColumnMappingDialog parent;
-	protected TRId trId;
-	protected ColumnData selectedColumn;
-	protected TabResource dimensionTR;
-	protected ColumnData referenceColumn;
-	protected EventBus eventBus;
+	private VerticalLayoutContainer vert;
+	private String itemIdSourceValueArg;
+	private String itemIdTargetValueArg;
+	private String itemIdBtnAdd;
+	private String itemIdBtnDel;
 
-	protected VerticalLayoutContainer vert;
-	protected String itemIdSourceValueArg;
-	protected String itemIdTargetValueArg;
-	protected String itemIdBtnAdd;
-	protected String itemIdBtnDel;
-
-	protected ColumnMappingList columnMappingList;
-	protected ArrayList<ColumnMappingData> mapping;
+	private ColumnMappingList columnMappingList;
+	private ArrayList<ColumnMappingData> mapping;
 
 	private TextButton btnSave;
 	private TextButton btnClose;
+	private ColumnMappingMessages msgs;
+	private CommonMessages msgsCommon;
 
 	/**
 	 * 
@@ -90,9 +88,7 @@ public class ColumnMappingPanel extends FramedPanel {
 			ColumnData selectedColumn, TabResource dimensionTR,
 			ColumnData referenceColumn, EventBus eventBus) {
 		this.parent = parent;
-		this.trId = trId;
 		this.selectedColumn = selectedColumn;
-		this.dimensionTR = dimensionTR;
 		this.referenceColumn = referenceColumn;
 		this.eventBus = eventBus;
 		thisPanel = this;
@@ -102,10 +98,16 @@ public class ColumnMappingPanel extends FramedPanel {
 				+ ", eventBus:" + eventBus + "]");
 		columnMappingList = new ColumnMappingList();
 		mapping = new ArrayList<ColumnMappingData>();
+		initMessages();
 		initPanel();
 		create();
 	}
 
+	protected void initMessages() {
+		msgs = GWT.create(ColumnMappingMessages.class);
+		msgsCommon = GWT.create(CommonMessages.class);
+	}
+
 	protected void initPanel() {
 		setHeaderVisible(false);
 		setBodyBorder(false);
@@ -120,10 +122,10 @@ public class ColumnMappingPanel extends FramedPanel {
 		container.setHeight(CONTAINERHEIGHT);
 		container.setWidth(CONTAINERWIDTH);
 
-		btnSave = new TextButton("Save");
+		btnSave = new TextButton(msgs.btnSaveText());
 		btnSave.setIcon(ResourceBundle.INSTANCE.save());
 		btnSave.setIconAlign(IconAlign.RIGHT);
-		btnSave.setToolTip("Save");
+		btnSave.setToolTip(msgs.btnSaveToolTip());
 		btnSave.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -134,10 +136,10 @@ public class ColumnMappingPanel extends FramedPanel {
 			}
 		});
 
-		btnClose = new TextButton("Close");
+		btnClose = new TextButton(msgs.btnCloseText());
 		btnClose.setIcon(ResourceBundle.INSTANCE.close());
 		btnClose.setIconAlign(IconAlign.RIGHT);
-		btnClose.setToolTip("Close");
+		btnClose.setToolTip(msgs.btnCloseToolTip());
 		btnClose.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -162,7 +164,7 @@ public class ColumnMappingPanel extends FramedPanel {
 		container.add(vert);
 		container.forceLayout();
 
-		FieldLabel rowsLabel = new FieldLabel(null, "Select rows");
+		FieldLabel rowsLabel = new FieldLabel(null, msgs.rowsLabel());
 		rowsLabel.getElement().applyStyles("font-weight:bold");
 
 		VerticalLayoutContainer vPanel = new VerticalLayoutContainer();
@@ -205,7 +207,7 @@ public class ColumnMappingPanel extends FramedPanel {
 				parent.saveMapping(columnMappingList);
 			}
 		} else {
-			UtilsGXT3.info("Attention", "Creates a valid mapping");
+			UtilsGXT3.info(msgsCommon.attention(), msgs.createAValidMapping());
 			btnSave.enable();
 		}
 
@@ -269,7 +271,8 @@ public class ColumnMappingPanel extends FramedPanel {
 						selectedColumn.getLabel(), null, 0, 0);
 
 				DimensionRowSelectionDialog dimensionRowSelectionDialog = new DimensionRowSelectionDialog(
-						selectedColumn, cellData, true, false, true, false, true, eventBus);
+						selectedColumn, cellData, true, false, true, false,
+						true, eventBus);
 				dimensionRowSelectionDialog
 						.addListener(sourceValueSelectedListener);
 				dimensionRowSelectionDialog.show();
@@ -278,7 +281,7 @@ public class ColumnMappingPanel extends FramedPanel {
 
 		});
 
-		comboSourceValue.setEmptyText("Select a source...");
+		comboSourceValue.setEmptyText(msgs.comboSourceValueEmptyText());
 		comboSourceValue.setWidth(COMBOWIDTH);
 		comboSourceValue.setEditable(false);
 		comboSourceValue.setTriggerAction(TriggerAction.ALL);
@@ -330,7 +333,8 @@ public class ColumnMappingPanel extends FramedPanel {
 								.getLabel(), null, 0, 0);
 
 				DimensionRowSelectionDialog dimensionRowSelectionDialog = new DimensionRowSelectionDialog(
-						referenceColumn, cellData, true, false, true, false, true, eventBus);
+						referenceColumn, cellData, true, false, true, false,
+						true, eventBus);
 				dimensionRowSelectionDialog
 						.addListener(targetValueSelectedListener);
 				dimensionRowSelectionDialog.show();
@@ -339,7 +343,7 @@ public class ColumnMappingPanel extends FramedPanel {
 
 		});
 
-		comboTargetValue.setEmptyText("Select a target...");
+		comboTargetValue.setEmptyText(msgs.comboTargetValueEmptyText());
 		comboTargetValue.setWidth(COMBOWIDTH);
 		comboTargetValue.setEditable(false);
 		comboTargetValue.setTriggerAction(TriggerAction.ALL);
@@ -440,7 +444,8 @@ public class ColumnMappingPanel extends FramedPanel {
 						selectedColumn.getLabel(), null, 0, 0);
 
 				DimensionRowSelectionDialog dimensionRowSelectionDialog = new DimensionRowSelectionDialog(
-						selectedColumn, cellData, true, false, true, false, true, eventBus);
+						selectedColumn, cellData, true, false, true, false,
+						true, eventBus);
 				dimensionRowSelectionDialog
 						.addListener(sourceValueSelectedListener);
 				dimensionRowSelectionDialog.show();
@@ -449,7 +454,7 @@ public class ColumnMappingPanel extends FramedPanel {
 
 		});
 
-		comboSourceValue.setEmptyText("Select a source...");
+		comboSourceValue.setEmptyText(msgs.comboSourceValueEmptyText());
 		comboSourceValue.setWidth(COMBOWIDTH);
 		comboSourceValue.setEditable(false);
 		comboSourceValue.setTriggerAction(TriggerAction.ALL);
@@ -501,7 +506,8 @@ public class ColumnMappingPanel extends FramedPanel {
 								.getLabel(), null, 0, 0);
 
 				DimensionRowSelectionDialog dimensionRowSelectionDialog = new DimensionRowSelectionDialog(
-						referenceColumn, cellData, true, false, true, false, true, eventBus);
+						referenceColumn, cellData, true, false, true, false,
+						true, eventBus);
 				dimensionRowSelectionDialog
 						.addListener(targetValueSelectedListener);
 				dimensionRowSelectionDialog.show();
@@ -510,7 +516,7 @@ public class ColumnMappingPanel extends FramedPanel {
 
 		});
 
-		comboTargetValue.setEmptyText("Select a target...");
+		comboTargetValue.setEmptyText(msgs.comboTargetValueEmptyText());
 		comboTargetValue.setWidth(COMBOWIDTH);
 		comboTargetValue.setEditable(false);
 		comboTargetValue.setTriggerAction(TriggerAction.ALL);
